unit frmMain;

interface

uses
{$IFDEF WIN32}
  Windows, Messages, Graphics, Menus, Controls, Forms, ExtCtrls, ComCtrls, Dialogs,
{$ENDIF}

{$IFDEF LINUX}
  QGraphics, QMenus, QControls, QForms, QExtCtrls,  QComCtrls, QDialogs, QTypes,
{$ENDIF}

  SysUtils, Variants, Classes, Types;
type
  TForm1 = class(TForm)
    Image1: TImage;
    StatusBar1: TStatusBar;
    MainMenu1: TMainMenu;
    File1: TMenuItem;
    Exit1: TMenuItem;
    SlideShow1: TMenuItem;
    Start1: TMenuItem;
    theTimer: TTimer;
    Pause1: TMenuItem;
    procedure Exit1Click(Sender: TObject);
    procedure Start1Click(Sender: TObject);
    procedure theTimerTimer(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure Pause1Click(Sender: TObject);
    {$IFDEF WIN32}
    procedure Image1Progress(Sender: TObject; Stage: TProgressStage;
      PercentDone: Byte; RedrawNow: Boolean; const R: TRect;
      const Msg: String);
    {$ENDIF}
    {$IFDEF LINUX}
    procedure Image1Progress(Sender: TObject; Stage: TProgressStage;
      PercentDone: Byte; RedrawNow: Boolean; const R: TRect;
      const Msg: WideString; var Continue: Boolean);
    {$ENDIF}
  private
    { Private declarations }
    bStarted : boolean;
    bPaused  : boolean;
    thePics : TStringList;
    FCurSlot : integer;
    procedure StartSlideShow(const dir : string;delay : integer);
    procedure DisplayPicture(const fname : string);
    procedure DoImageProgress(PercentDone : Byte);
  public
    { Public declarations }
  end;

var
  Form1: TForm1;

implementation

uses dlgDirectory {$IFDEF WIN32}, JPEG {$ENDIF};

{$R *.xfm}

procedure BuildFileList( theList : TStringList; dir, SearchMask : string);
var
  srec : TSearchRec;
  SearchSpec : string;

begin
  theList.Clear;
  SearchSpec := dir + SearchMask;
  if FindFirst(SearchSpec, faAnyFile, srec) = 0 then
  begin
    repeat
      if srec.Name[1] <> '.' then
      begin
        // add this filename to the list..
        theList.Add( dir + PathDelim + srec.Name );
      end;
    until FindNext(srec) <> 0;
    FindClose(srec);
  end;

  // sort the list
  theList.Sort;
end;

procedure TForm1.Exit1Click(Sender: TObject);
begin
  Close;
end;

procedure TForm1.Start1Click(Sender: TObject);
var
  frm : TfrmSelectDir;
begin
  // are we starting up?
  if not bStarted then
  begin
    // execute the start code
    // bring up the select directory dialog
    frm := TfrmSelectDir.Create(nil);
    try
      if frm.ShowModal = mrOK then
      begin
        StartSlideShow(frm.Directory,frm.Delay);
      end;
    finally
      frm.Free;
    end;
  end
  else
  begin
    // execute the stop code
    theTimer.Enabled := false;
  end;

  // finally, flip the boolean and set the caption appropriately.
  bStarted := not bStarted;
  if bStarted then
    Start1.Caption := '&Stop'
  else
    Start1.Caption := '&Start';

  Pause1.Visible := bStarted;
end;

procedure TForm1.StartSlideShow(const dir: string; delay: integer);
var
  srchmask : string;
begin
  // set the timer to the appropriate delay
  theTimer.Interval := delay * 1000;

  srchmask := PathDelim + '*.jpg';

  BuildFileList( thePics, dir, srchmask);

  if thePics.Count = 0 then
    raise Exception.CreateFmt('No pictures in the %s directory!',[dir]);

  FCurSlot := 0;
  DisplayPicture( thePics[ FCurSlot ] );
end;

procedure TForm1.theTimerTimer(Sender: TObject);
begin
  // time to display another picture
  inc(FCurSlot);
  if FCurSlot > thePics.Count-1 then
    FCurSlot := 0;

  DisplayPicture( thePics[ FCurSlot ] );
end;

procedure TForm1.FormCreate(Sender: TObject);
begin
  thePics := TStringList.Create;
end;

procedure TForm1.DisplayPicture(const fname: string);
begin
  theTimer.Enabled := false;
  StatusBar1.SimpleText := 'Loading ' + fname;
  try
    Image1.Picture.LoadFromFile(fname);
  except
    on e : exception do
    begin
      e.message := Format('Error loading file %s. Exception: %s',[fname,e.message]);
      raise;
    end;
  end;
  StatusBar1.SimpleText := 'Loaded ' + fname;
  //theTimer.Enabled := true;
end;


procedure TForm1.Pause1Click(Sender: TObject);
begin
  // do the pause
  // toggle the state
  bPaused := not bPaused;
  if bPaused then
    Pause1.Caption := '&Resume'
  else
    Pause1.Caption := '&Pause';

  theTimer.Enabled := not bPaused;
end;

{$IFDEF WIN32}
procedure TForm1.Image1Progress(Sender: TObject; Stage: TProgressStage;
  PercentDone: Byte; RedrawNow: Boolean; const R: TRect;
  const Msg: String);
begin
  DoImageProgress(PercentDone);
end;
{$ENDIF}


{$IFDEF LINUX}
procedure TForm1.Image1Progress(Sender: TObject; Stage: TProgressStage;
  PercentDone: Byte; RedrawNow: Boolean; const R: TRect;
  const Msg: WideString; var Continue: Boolean);
begin
  DoImageProgress(PercentDone);
end;
{$ENDIF}

procedure TForm1.DoImageProgress(PercentDone : Byte);
begin
  if PercentDone = 100 then
    theTimer.Enabled := true;
end;

end.
